Merge branch 'main' into avm99963-monorail

Merged commit 34d8229ae2b51fb1a15bd208e6fe6185c94f6266

GitOrigin-RevId: 7ee0917f93a577e475f8e09526dd144d245593f4
diff --git a/tracker/template_helpers.py b/tracker/template_helpers.py
index 1f15bcc..afa015b 100644
--- a/tracker/template_helpers.py
+++ b/tracker/template_helpers.py
@@ -1,7 +1,6 @@
-# Copyright 2018 The Chromium Authors. All rights reserved.
-# Use of this source code is governed by a BSD-style
-# license that can be found in the LICENSE file or at
-# https://developers.google.com/open-source/licenses/bsd
+# Copyright 2018 The Chromium Authors
+# Use of this source code is governed by a BSD-style license that can be
+# found in the LICENSE file.
 
 """Helper functions for issue template servlets"""
 from __future__ import print_function
@@ -19,7 +18,7 @@
 from tracker import tracker_bizobj
 from tracker import tracker_constants
 from tracker import tracker_helpers
-from proto import tracker_pb2
+from mrproto import tracker_pb2
 
 MAX_NUM_PHASES = 6
 
@@ -47,9 +46,7 @@
   content = framework_helpers.WordWrapSuperLongLines(content, max_cols=75)
   status = post_data.get('status', '')
   owner_str = post_data.get('owner', '')
-  # TODO(crbug.com/monorail/10936): switch when convert /p to flask
-  # labels = post_data.getlist('label')
-  labels = post_data.getall('label')
+  labels = post_data.getlist('label')
   field_val_strs = collections.defaultdict(list)
   for fd in config.field_defs:
     field_value_key = 'custom_%d' % fd.field_id
@@ -230,8 +227,8 @@
 
 
 def GetIssueFromTemplate(template, project_id, reporter_id):
   # type: (proto.tracker_pb2.TemplateDef, int, int) ->
   #     proto.tracker_pb2.Issue
   """Build a templated issue from TemplateDef.
 
   Args:
@@ -230,8 +227,8 @@
 
 def GetIssueFromTemplate(template, project_id, reporter_id):
-  # type: (proto.tracker_pb2.TemplateDef, int, int) ->
-  #     proto.tracker_pb2.Issue
+  # type: (mrproto.tracker_pb2.TemplateDef, int, int) ->
+  #     mrproto.tracker_pb2.Issue
   """Build a templated issue from TemplateDef.
 